# Vodi

This cli is a helper tool for developers aiming to speed up development and release process

## currently implemented

`vodi get envs` retrieves a list of environments
`vodi get env <env>` detailed view of an environment including deployments (requires openshift CLI and access to the environment)
`vodi get projects` retrieves a list of projects on bitbucket
`vodi get project <proj>` detailed view of a project including repositories

